function sf_isoreactor(block)
% In order to know more on Level-2 M-file S-function, refer to the MatLab documentation.

setup(block);

function setup(block)

% Register number of dialog parameters
block.NumDialogPrms = 0;

% Register number of ports
nu = 4; ny = 3;
block.NumInputPorts  = nu;
block.NumOutputPorts = ny;

% Setup port properties to be inherited or dynamic
block.SetPreCompInpPortInfoToDynamic;
block.SetPreCompOutPortInfoToDynamic;

for i = 1:nu
    block.InputPort(i).Dimensions = 1;
    block.InputPort(i).DirectFeedthrough = true;
end

for i = 1:ny
    block.OutputPort(i).Dimensions = 1;
end

block.SampleTimes = [0 0];

% Setup Dwork
block.NumContStates = 3;

block.RegBlockMethod('InitializeConditions',    @InitializeConditions);
block.RegBlockMethod('Outputs',                 @Outputs);
block.RegBlockMethod('Derivatives',             @Derivatives);
block.RegBlockMethod('SetInputPortSamplingMode',@SetInpPortFrameData);


function SetInpPortFrameData(block, idx, fd)
  
block.InputPort(idx).SamplingMode = fd;
for i = 1:block.NumOutputPorts
    block.OutputPort(i).SamplingMode = fd;
end


function InitializeConditions(block)

load steadystate % y0
block.ContStates.Data = y0;


function Outputs(block)

parameters
% State variables
c = block.ContStates.Data;

for i = 1:block.NumInputPorts
    u(i) = block.InputPort(i).Data;
end

% Disturbances
q   = u(1) + qbias;
cAf = u(2) + cAfbias;
cBf = u(3) + cBfbias;
cCf = u(4) + cCfbias;

% Non-linear model
model

% Output variables
yout = c - cbias;
for i = 1:block.NumOutputPorts
    block.OutputPort(i).Data = yout(i);
end


function Derivatives(block)

parameters
% State variables
c = block.ContStates.Data;

for i = 1:block.NumInputPorts
    u(i) = block.InputPort(i).Data;
end

% Disturbances
q   = u(1) + qbias;
cAf = u(2) + cAfbias;
cBf = u(3) + cBfbias;
cCf = u(4) + cCfbias;

% Non-linear model
model

block.Derivatives.Data = DYDT;

